pyxmpp.jabberd.all

Package pyxmpp :: Package jabberd :: Module all |
[hide private]

# Module all

source code

Convenience module containing most important objects fr pyxmpp.jabberd package.

Suggested usage:: import pyxmpp.jabberd.all

(imports all important names into pyxmpp.jabberd namespace)

Variables | [hide private]
| __revision__ = ``'``$Id: __init__.py 477 2004-12-29 13:25:42Z jajc``...``
| __package__ = ``'``pyxmpp.jabberd``'``
| name = ``'``pyxmpp``'``

Imports: pyxmpp, ComponentStream, Component

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: __init__.py 477 2004-12-29 13:25:42Z jajcus $'